Changelog
=========


1.0a2 (2019-08-16)
------------------

- Fix regular expressions for file extension validation [Andreas Mantke]
- Add import for Invalid to the addoncenter module [Andreas Mantke]
- Add necessary imports for virus scanning with
  collective.clamaav [Andreas Mantke]
- Fix title strings and field namings [Andreas Mantke]
- Update localization template file and localization files and
  add the missing German localization strings [Andreas Mantke]



1.0a1 (2019-08-13)
------------------

- Initial release.
  [andreasma]
